@@ -63,6 +63,8 @@ gns_resolve_name (int af, const char *name, struct userdata *u)
   int out[2];
   pid_t pid;
 
+  if (0 == getuid ())
+    return -2; /* GNS via NSS is NEVER for root */
   if (0 != pipe (out))
     return -1;
   pid = fork ();
@@ -71,7 +73,8 @@ gns_resolve_name (int af, const char *name, struct userdata *u)
   if (0 == pid)
   {
     char *argv[] = { "gnunet-gns",
-                     "-r",
+                     "-r", /* Raw output for easier parsing */
+                     "-d", /* DNS compatibility (allow IDNA names, no UTF-8) */
                      "-t",
                      (AF_INET6 == af) ? "AAAA" : "A",
                      "-u",
@@ -146,4 +149,5 @@ gns_resolve_name (int af, const char *name, struct userdata *u)
   return 0;
 }
 
+
 /* end of nss_gns_query.c */
