@@ -16,7 +16,7 @@
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
      SPDX-License-Identifier: AGPL3.0-or-later
-*/
+ */
 
 /**
  * @author Christian Grothoff
@@ -85,8 +85,8 @@ extern "C" {
 #define GNUNET_MESSAGE_TYPE_RESOLVER_RESPONSE 5
 
 /*******************************************************************************
- * AGPL source code download
- * *****************************************************************************/
+* AGPL source code download
+* *****************************************************************************/
 
 /**
  * Message to request source code link.
@@ -1940,6 +1940,23 @@ extern "C" {
  */
 #define GNUNET_MESSAGE_TYPE_IDENTITY_DELETE 631
 
+/**
+ * First message send from identity client to service to
+ * lookup a single ego.  The service will respond with a
+ * #GNUNET_MESSAGE_TYPE_IDENTITY_UPDATE message if the ego
+ * exists, or a #GNUNET_MESSAGE_TYPE_IDENTITY_RESULT_CODE if not.
+ */
+#define GNUNET_MESSAGE_TYPE_IDENTITY_LOOKUP 632
+
+/**
+ * First message send from identity client to service to lookup a
+ * single ego matching the given suffix (longest match).  The service
+ * will respond with a #GNUNET_MESSAGE_TYPE_IDENTITY_UPDATE message if
+ * the ego exists, or a #GNUNET_MESSAGE_TYPE_IDENTITY_RESULT_CODE if
+ * not.
+ */
+#define GNUNET_MESSAGE_TYPE_IDENTITY_LOOKUP_BY_SUFFIX 633
+
 
 /*******************************************************************************
  * REVOCATION message types
@@ -2699,15 +2716,17 @@ extern "C" {
 
 /**************************************************
  *
- * CREDENTIAL MESSAGE TYPES
+ * ABD MESSAGE TYPES
  */
-#define GNUNET_MESSAGE_TYPE_CREDENTIAL_VERIFY 981
+#define GNUNET_MESSAGE_TYPE_ABD_VERIFY 981
 
-#define GNUNET_MESSAGE_TYPE_CREDENTIAL_VERIFY_RESULT 982
+#define GNUNET_MESSAGE_TYPE_ABD_VERIFY_RESULT 982
 
-#define GNUNET_MESSAGE_TYPE_CREDENTIAL_COLLECT 983
+#define GNUNET_MESSAGE_TYPE_ABD_COLLECT 983
 
-#define GNUNET_MESSAGE_TYPE_CREDENTIAL_COLLECT_RESULT 984
+#define GNUNET_MESSAGE_TYPE_ABD_COLLECT_RESULT 984
+
+#define GNUNET_MESSAGE_TYPE_ABD_INTERMEDIATE_RESULT 985
 
 /******************************************************************************/
 
@@ -3031,8 +3050,8 @@ extern "C" {
 
 
 /*******************************************************
-  NEW (TNG) Transport service
-  ******************************************************* */
+   NEW (TNG) Transport service
+ ******************************************************* */
 
 /**
  * @brief inform transport to add an address of this peer
@@ -3141,6 +3160,11 @@ extern "C" {
  */
 #define GNUNET_MESSAGE_TYPE_TRANSPORT_COMMUNICATOR_BACKCHANNEL_INCOMING 1220
 
+/**
+ * Transport signalling incoming backchannel message to a communicator.
+ */
+#define GNUNET_MESSAGE_TYPE_TRANSPORT_FLOW_CONTROL 1221
+
 
 /**
  * Message sent to indicate to the transport that a monitor
