@@ -946,7 +946,7 @@ GNUNET_SERVICE_MAIN
   GNUNET_MQ_handler_end ());
 
 
-#if defined(LINUX) && defined(__GLIBC__)
+#if defined(__linux__) && defined(__GLIBC__)
 #include <malloc.h>
 
 /**
@@ -960,6 +960,7 @@ GNUNET_REVOCATION_memory_init ()
   malloc_trim (0);
 }
 
+
 #endif
 
 
