@@ -704,6 +704,7 @@ pack (const char *hostname,
   return GNUNET_OK;
 }
 
+
 static void
 cache_answers (const char *name,
                struct GNUNET_DNSPARSER_Record *records,
@@ -738,6 +739,7 @@ cache_answers (const char *name,
   }
 }
 
+
 /**
  * We got a result from DNS. Add it to the cache and
  * see if we can make our client happy...
@@ -1360,18 +1362,21 @@ GNUNET_SERVICE_MAIN (
   GNUNET_MQ_handler_end ());
 
 
-#if defined(LINUX) && defined(__GLIBC__)
+#if defined(__linux__) && defined(__GLIBC__)
 #include <malloc.h>
 
 /**
  * MINIMIZE heap size (way below 128k) since this process doesn't need much.
  */
-void __attribute__ ((constructor)) GNUNET_RESOLVER_memory_init ()
+void __attribute__ ((constructor))
+GNUNET_RESOLVER_memory_init ()
 {
   mallopt (M_TRIM_THRESHOLD, 4 * 1024);
   mallopt (M_TOP_PAD, 1 * 1024);
   malloc_trim (0);
 }
+
+
 #endif
 
 
