@@ -323,6 +323,8 @@ socket_set_nosigpipe (const struct GNUNET_NETWORK_Handle *h)
     return GNUNET_SYSERR;
   return GNUNET_OK;
 }
+
+
 #endif
 
 
@@ -631,7 +633,7 @@ GNUNET_NETWORK_socket_free_memory_only_ (struct GNUNET_NETWORK_Handle *desc)
  * @return NULL on error (including not supported on target platform)
  */
 struct GNUNET_NETWORK_Handle *
-GNUNET_NETWORK_socket_box_native (SOCKTYPE fd)
+GNUNET_NETWORK_socket_box_native (int fd)
 {
   struct GNUNET_NETWORK_Handle *ret;
 
@@ -960,7 +962,7 @@ GNUNET_NETWORK_socket_disable_corking (struct GNUNET_NETWORK_Handle *desc)
 {
   int ret = 0;
 
-#if LINUX
+#ifdef __linux__
   int value = 0;
 
   if (0 !=
@@ -1385,4 +1387,5 @@ GNUNET_NETWORK_socket_select (struct GNUNET_NETWORK_FDSet *rfds,
                   GNUNET_TIME_UNIT_FOREVER_REL.rel_value_us) ? NULL : &tv);
 }
 
+
 /* end of network.c */
