@@ -76,6 +76,7 @@ test_normal_rw ()
   return 0;
 }
 
+
 static int
 test_nullstring_rw ()
 {
@@ -103,6 +104,7 @@ test_nullstring_rw ()
   return 0;
 }
 
+
 static int
 test_emptystring_rw ()
 {
@@ -130,6 +132,7 @@ test_emptystring_rw ()
   return 0;
 }
 
+
 static int
 test_bigstring_rw ()
 {
@@ -159,6 +162,7 @@ test_bigstring_rw ()
   return 0;
 }
 
+
 static int
 test_bigmeta_rw ()
 {
@@ -192,10 +196,11 @@ test_bigmeta_rw ()
   return 0;
 }
 
+
 static int
 test_directory_r ()
 {
-#if LINUX
+#ifdef __linux__
   char *msg;
   char readResult[200];
   struct GNUNET_BIO_ReadHandle *fileR;
@@ -212,6 +217,7 @@ test_directory_r ()
   return 0;
 }
 
+
 static int
 test_nullfile_rw ()
 {
@@ -238,7 +244,7 @@ test_nullfile_rw ()
 static int
 test_fullfile_rw ()
 {
-#ifdef LINUX
+#ifdef __linux__
   /* /dev/full only seems to exist on Linux */
   char *msg;
   int64_t testNum;
@@ -287,6 +293,7 @@ test_fullfile_rw ()
   return 0;
 }
 
+
 static int
 test_fakestring_rw ()
 {
@@ -315,6 +322,7 @@ test_fakestring_rw ()
   return 0;
 }
 
+
 static int
 test_fakemeta_rw ()
 {
@@ -345,6 +353,7 @@ test_fakemeta_rw ()
   return 0;
 }
 
+
 static int
 test_fakebigmeta_rw ()
 {
@@ -375,6 +384,7 @@ test_fakebigmeta_rw ()
   return 0;
 }
 
+
 static int
 check_string_rw ()
 {
@@ -385,6 +395,7 @@ check_string_rw ()
   return 0;
 }
 
+
 static int
 check_metadata_rw ()
 {
@@ -394,6 +405,7 @@ check_metadata_rw ()
   return 0;
 }
 
+
 static int
 check_file_rw ()
 {
@@ -404,6 +416,7 @@ check_file_rw ()
   return 0;
 }
 
+
 int
 main (int argc, char *argv[])
 {
@@ -414,4 +427,5 @@ main (int argc, char *argv[])
   return 0;
 }
 
+
 /* end of test_bio.c */
